==> ejc-quality-impl-3.0.0-20240626.011032-54-sources.jar: com/ejianc/business/quality/entity/SysDocStandardLibEntity.java <==
package com.ejianc.business.quality.entity;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;

import java.sql.Date;

/**
 * @Author: LCL
 * @Date: 2024/5/10 下午2:52
 * @Description: 体系文件-标准库
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@EqualsAndHashCode(callSuper = true)
@TableName("ejc_quality_system_documents_standard_library")
public class SysDocStandardLibEntity extends BaseEntity {
    /**
     * 分类(本部、分子公司、项目)
     *
     * @see com.ejianc.business.quality.enums.QualityTypeEnum
     */
    @TableField(value = "type")
    private String type;

    /**
     * 来源(OA、ZTPC)
     *
     * @see com.ejianc.business.quality.enums.SystemDocumentsOriginEnum
     */
    @TableField(value = "origin")
    private String origin;

    /**
     * 文件编号
     */
    @TableField(value = "wjbh")
    private String wjbh;

    /**
     * 文件名称
     */
    @TableField(value = "wjmc")
    private String wjmc;

    /**
     * 文件内容 url地址
     */
    @TableField(value = "wjnr")
    private String wjnr;

    /**
     * 适用项目类别(核电、火电、送变电、风电、光伏、市政、房建、通用)
     *
     * @see com.ejianc.business.quality.enums.ApplicableProjectCategoriesEnum
     */
    @TableField(value = "syxmlb")
    private String syxmlb;

    /**
     * 适用范围(公司部门、公司直管项目、公司所属单位/项目)
     *
     * @see com.ejianc.business.quality.enums.ApplicableScopeEnum
     */
    @TableField(value = "syfw")
    private String syfw;

    /**
     * 状态(启用、废止(修订)、废止)
     *
     * @see com.ejianc.business.quality.enums.SystemDocumentsStatusEnum
     */
    @TableField(value = "zt")
    private String zt;

    /**
     * 备注
     */
    @TableField(value = "bz")
    private String bz;

    /**
     * 发布日期
     */
    @TableField(value = "fbrq")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date fbrq;

    /**
     * 实施日期
     */
    @TableField(value = "ssrq")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date ssrq;

    /**
     * 体系结构号
     */
    @TableField(value = "txjgh")
    private String txjgh;

    /**
     * 归属管理体系
     *
     * @see com.ejianc.business.quality.enums.ManagementSystemEnum
     */
    @TableField(value = "gltx")
    private String gltx;

    /**
     * 编码
     */
    @TableField(value = "bm")
    private String bm;

    /**
     * 编制单位
     */
    @TableField(value = "bzdw")
    private String bzdw;

    /**
     * 编制部门
     */
    @TableField(value = "bzbm")
    private String bzbm;

    /**
     * 标准管理分类
     */
    @TableField(value = "bzglfl")
    private String bzglfl;

    /**
     * 标准分类
     */
    @TableField(value = "bzfl")
    private String bzfl;

    /**
     * 标准分类(小类)
     */
    @TableField(value = "bzdlxl")
    private String bzdlxl;

    /**
     * 标准分类(小小类)
     */
    @TableField(value = "bzflxxl")
    private String bzflxxl;

    /**
     * 标准级别
     */
    @TableField(value = "bzjb")
    private String bzjb;

    /**
     * 复审时间
     */
    @TableField(value = "fssj")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date fssj;

    /**
     * 替代信息
     */
    @TableField(value = "tdxx")
    private String tdxx;

    /**
     * 归口单位
     */
    @TableField(value = "gkdw")
    private String gkdw;

    /**
     * 版本
     */
    @TableField(value = "bb")
    private String bb;

    /**
     * 起草人
     */
    @TableField(value = "qcr")
    private String qcr;

    /**
     * 引用标准
     */
    @TableField(value = "yybz")
    private String yybz;
    /**
     * 编制人账号
     */
    @TableField(value = "prepared_user_code")
    private String preparedUserCode;

    /**
     * 所属项目部Id
     */
    @TableField(value = "org_id")
    private Long orgId;

    /**
     * 所属项目部名称
     */
    @TableField(value = "org_name")
    private String orgName;

    /**
     * 项目部上级组织Id
     */
    @TableField(value = "parent_org_id")
    private Long parentOrgId;

    /**
     * 项目部上级组织名称
     */
    @TableField(value = "parent_org_name")
    private String parentOrgName;
}

==> ejc-quality-impl-3.0.0-20250513.021223-129-sources.jar: com/ejianc/business/quality/entity/SysDocStandardLibEntity.java <==
package com.ejianc.business.quality.entity;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;

import java.sql.Date;

/**
 * @Author: LCL
 * @Date: 2024/5/10 下午2:52
 * @Description: 体系文件-标准库
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@EqualsAndHashCode(callSuper = true)
@TableName("ejc_quality_system_documents_standard_library")
public class SysDocStandardLibEntity extends BaseEntity {
    /**
     * 创建者姓名
     */
    @TableField(value = "create_user_name")
    private String createUserName;
    /**
     * 更新着姓名
     */
    @TableField(value = "update_user_name")
    private String updateUserName;
    /**
     * 分类(本部、分子公司、项目)
     *
     * @see com.ejianc.business.quality.enums.QualityTypeEnum
     */
    @TableField(value = "type")
    private String type;

    /**
     * 来源(OA、ZTPC)
     *
     * @see com.ejianc.business.quality.enums.SystemDocumentsOriginEnum
     */
    @TableField(value = "origin")
    private String origin;

    /**
     * 文件编号
     */
    @TableField(value = "wjbh")
    private String wjbh;

    /**
     * 文件名称
     */
    @TableField(value = "wjmc")
    private String wjmc;

    /**
     * 文件内容 url地址
     */
    @TableField(value = "wjnr")
    private String wjnr;

    /**
     * 适用项目类别(核电、火电、送变电、风电、光伏、市政、房建、通用)
     *
     * @see com.ejianc.business.quality.enums.ApplicableProjectCategoriesEnum
     */
    @TableField(value = "syxmlb")
    private String syxmlb;

    /**
     * 适用范围(公司部门、公司直管项目、公司所属单位/项目)
     *
     * @see com.ejianc.business.quality.enums.ApplicableScopeEnum
     */
    @TableField(value = "syfw")
    private String syfw;

    /**
     * 状态(启用、废止(修订)、废止)
     *
     * @see com.ejianc.business.quality.enums.SystemDocumentsStatusEnum
     */
    @TableField(value = "zt")
    private String zt;

    /**
     * 备注
     */
    @TableField(value = "bz")
    private String bz;

    /**
     * 发布日期
     */
    @TableField(value = "fbrq")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date fbrq;

    /**
     * 实施日期
     */
    @TableField(value = "ssrq")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date ssrq;

    /**
     * 归属管理体系
     *
     * @see com.ejianc.business.quality.enums.ManagementSystemEnum
     */
    @TableField(value = "gltx")
    private String gltx;

    /**
     * 编码
     */
    @TableField(value = "bm")
    private String bm;

    /**
     * 编制单位
     */
    @TableField(value = "bzdw")
    private String bzdw;

    /**
     * 编制部门
     */
    @TableField(value = "bzbm")
    private String bzbm;

    /**
     * 复审时间
     */
    @TableField(value = "fssj")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date fssj;

    /**
     * 替代信息
     */
    @TableField(value = "tdxx")
    private String tdxx;

    /**
     * 归口单位
     */
    @TableField(value = "gkdw")
    private String gkdw;

    /**
     * 版本
     */
    @TableField(value = "bb")
    private String bb;

    /**
     * 起草人
     */
    @TableField(value = "qcr")
    private String qcr;

    /**
     * 引用标准
     */
    @TableField(value = "yybz")
    private String yybz;
    /**
     * 编制人账号
     */
    @TableField(value = "prepared_user_code")
    private String preparedUserCode;

    /**
     * 所属项目部Id
     */
    @TableField(value = "org_id")
    private Long orgId;

    /**
     * 所属项目部名称
     */
    @TableField(value = "org_name")
    private String orgName;

    /**
     * 项目部上级组织Id
     */
    @TableField(value = "parent_org_id")
    private Long parentOrgId;

    /**
     * 项目部上级组织名称
     */
    @TableField(value = "parent_org_name")
    private String parentOrgName;
}
